You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by al...@apache.org on 2013/01/17 12:06:20 UTC

svn commit: r1434615 [11/11] - in /openoffice/branches/alg/clibboard: ./ ext_libraries/apr-util/ ext_libraries/apr/ extras/l10n/source/eu/ main/ main/boost/ main/canvas/source/cairo/ main/cli_ure/source/basetypes/ main/cli_ure/source/native/ main/cli_u...

Modified: openoffice/branches/alg/clibboard/main/xmerge/source/minicalc/converter.xml
URL: http://svn.apache.org/viewvc/openoffice/branches/alg/clibboard/main/xmerge/source/minicalc/converter.xml?rev=1434615&r1=1434614&r2=1434615&view=diff
==============================================================================
--- openoffice/branches/alg/clibboard/main/xmerge/source/minicalc/converter.xml (original)
+++ openoffice/branches/alg/clibboard/main/xmerge/source/minicalc/converter.xml Thu Jan 17 11:06:13 2013
@@ -29,7 +29,7 @@
         <converter-description>
             StarCalc XML to/from Minicalc 6.4 conversion
         </converter-description>
-        <converter-vendor>OpenOffice.org</converter-vendor>
+        <converter-vendor>Apache OpenOffice</converter-vendor>
         <converter-class-impl>
             org.openoffice.xmerge.converter.xml.sxc.minicalc.PluginFactoryImpl
         </converter-class-impl>

Modified: openoffice/branches/alg/clibboard/main/xmerge/source/pexcel/converter.xml
URL: http://svn.apache.org/viewvc/openoffice/branches/alg/clibboard/main/xmerge/source/pexcel/converter.xml?rev=1434615&r1=1434614&r2=1434615&view=diff
==============================================================================
--- openoffice/branches/alg/clibboard/main/xmerge/source/pexcel/converter.xml (original)
+++ openoffice/branches/alg/clibboard/main/xmerge/source/pexcel/converter.xml Thu Jan 17 11:06:13 2013
@@ -29,7 +29,7 @@
         <converter-description>
             StarCalc XML to/from Pocket Excel 2.0 conversion
         </converter-description>
-        <converter-vendor>OpenOffice.org</converter-vendor>
+        <converter-vendor>Apache OpenOffice</converter-vendor>
         <converter-class-impl>
             org.openoffice.xmerge.converter.xml.sxc.pexcel.PluginFactoryImpl
         </converter-class-impl>

Modified: openoffice/branches/alg/clibboard/main/xmerge/source/pocketword/converter.xml
URL: http://svn.apache.org/viewvc/openoffice/branches/alg/clibboard/main/xmerge/source/pocketword/converter.xml?rev=1434615&r1=1434614&r2=1434615&view=diff
==============================================================================
--- openoffice/branches/alg/clibboard/main/xmerge/source/pocketword/converter.xml (original)
+++ openoffice/branches/alg/clibboard/main/xmerge/source/pocketword/converter.xml Thu Jan 17 11:06:13 2013
@@ -30,10 +30,10 @@
             Pocket Word
         </converter-display-name>
         <converter-description>
-            OpenOffice Writer XML to/from Pocket Word conversion.
+            OpenOffice.org XML Writer to/from Pocket Word conversion.
         </converter-description>
         <converter-vendor>
-            OpenOffice.org
+            Apache OpenOffice
         </converter-vendor>
         <converter-class-impl>
             org.openoffice.xmerge.converter.xml.sxw.pocketword.PluginFactoryImpl

Modified: openoffice/branches/alg/clibboard/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/DocumentDeserializerImpl.java
URL: http://svn.apache.org/viewvc/openoffice/branches/alg/clibboard/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/DocumentDeserializerImpl.java?rev=1434615&r1=1434614&r2=1434615&view=diff
==============================================================================
--- openoffice/branches/alg/clibboard/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/DocumentSerializerImpl.java (original)
+++ openoffice/branches/alg/clibboard/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/DocumentSerializerImpl.java Thu Jan 17 11:06:13 2013
@@ -48,7 +48,7 @@ import java.io.IOException;
  * org.openoffice.xmerge.converter.xml.sxw.pocketword.PluginFactoryImpl
  * PluginFactoryImpl}.</p>
  *
- * <p>This converts an OpenOffice Writer XML files to a Pocket Word file<.</p>
+ * <p>This converts an OpenOffice.org XML Writer files to a Pocket Word file<.</p>
  *
  * @author      Mark Murnane
  * @version 1.1

Modified: openoffice/branches/alg/clibboard/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/PluginFactoryImpl.java
URL: http://svn.apache.org/viewvc/openoffice/branches/alg/clibboard/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/PluginFactoryImpl.java?rev=1434615&r1=1434614&r2=1434615&view=diff
==============================================================================
--- openoffice/branches/alg/clibboard/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/PluginFactoryImpl.java (original)
+++ openoffice/branches/alg/clibboard/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/PluginFactoryImpl.java Thu Jan 17 11:06:13 2013
@@ -69,7 +69,7 @@ public final class PluginFactoryImpl ext
 
     /**
      *  <p>The <code>DocumentSerializer</code> is used to convert 
-     *  from the OpenOffice Writer <code>Document</code> format 
+     *  from the OpenOffice.org XML Writer <code>Document</code> format 
      *  to the Pocket Word <code>Document</code> format.</p>
      *
      *  <p>The <code>ConvertData</code> object is passed along to the
@@ -92,7 +92,7 @@ public final class PluginFactoryImpl ext
     /**
      *  The <code>DocumentDeserializer</code> is used to convert
      *  from the Pocket Word <code>Document</code> format to
-     *  the OpenOffice Writer <code>Document</code> format.</p>
+     *  the OpenOffice.org XML Writer <code>Document</code> format.</p>
      *
      *  The <code>ConvertData</code> object is passed along to the
      *  created <code>DocumentDeserializer</code> via its constructor.

Modified: openoffice/branches/alg/clibboard/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/PocketWordDocument.java
URL: http://svn.apache.org/viewvc/openoffice/branches/alg/clibboard/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/PocketWordDocument.java?rev=1434615&r1=1434614&r2=1434615&view=diff
==============================================================================
--- openoffice/branches/alg/clibboard/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/PocketWordDocument.java (original)
+++ openoffice/branches/alg/clibboard/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/PocketWordDocument.java Thu Jan 17 11:06:13 2013
@@ -41,7 +41,7 @@ import java.util.Vector;
  * <p>Class representing a Pocket Word Document.</p>
  *
  * <p><code>PocketWordDocument</code> is used to create new Pocket Word documents
- *    and to read existing data to allow for conversion to OpenOffice Writer 
+ *    and to read existing data to allow for conversion to OpenOffice.org XML Writer 
  *    format.</p>
  *
  * @author  Mark Murnane

Modified: openoffice/branches/alg/clibboard/main/xmerge/source/wordsmith/converter.xml
URL: http://svn.apache.org/viewvc/openoffice/branches/alg/clibboard/main/xmerge/source/wordsmith/converter.xml?rev=1434615&r1=1434614&r2=1434615&view=diff
==============================================================================
--- openoffice/branches/alg/clibboard/main/xmerge/source/wordsmith/converter.xml (original)
+++ openoffice/branches/alg/clibboard/main/xmerge/source/wordsmith/converter.xml Thu Jan 17 11:06:13 2013
@@ -27,7 +27,7 @@
         <converter-description>
             StarWriter XML to/from WordSmith conversion
         </converter-description>
-        <converter-vendor>OpenOffice.org</converter-vendor>
+        <converter-vendor>Apache OpenOffice</converter-vendor>
         <converter-class-impl>
             org.openoffice.xmerge.converter.xml.sxw.wordsmith.PluginFactoryImpl
         </converter-class-impl>

Modified: openoffice/branches/alg/clibboard/main/xmerge/source/xmerge/build.xml
URL: http://svn.apache.org/viewvc/openoffice/branches/alg/clibboard/main/xmerge/source/xmerge/build.xml?rev=1434615&r1=1434614&r2=1434615&view=diff
==============================================================================
--- openoffice/branches/alg/clibboard/main/xmerge/source/xmerge/build.xml (original)
+++ openoffice/branches/alg/clibboard/main/xmerge/source/xmerge/build.xml Thu Jan 17 11:06:13 2013
@@ -64,8 +64,8 @@
                          includes="**/*.properties" />
             <manifest>
                 <attribute name="Main-Class" value="org.openoffice.xmerge.test.Driver"/>
-                <attribute name="Specification-Title" value="OpenOffice XMerge Framework"/>
-                <attribute name="Specification-Vendor" value="OpenOffice.org"/>
+                <attribute name="Specification-Title" value="Apache OpenOffice XMerge Framework"/>
+                <attribute name="Specification-Vendor" value="Apache OpenOffice"/>
                 <attribute name="Specification-Version" value="0.6.0"/>
                 <attribute name="Implementation-Version" value="#IMPL-VERSION#"/>
                 <attribute name="Class-Path" value="xml-apis.jar xercesImpl.jar serializer.jar"/>

Modified: openoffice/branches/alg/clibboard/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/dom/DOMDocument.java
URL: http://svn.apache.org/viewvc/openoffice/branches/alg/clibboard/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/dom/DOMDocument.java?rev=1434615&r1=1434614&r2=1434615&view=diff
==============================================================================
--- openoffice/branches/alg/clibboard/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/dom/DOMDocument.java (original)
+++ openoffice/branches/alg/clibboard/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/dom/DOMDocument.java Thu Jan 17 11:06:13 2013
@@ -369,7 +369,7 @@ public class DOMDocument
 
     /**
      *  <p>Creates a new DOM <code>Document</code> containing minimum
-     *  OpenOffice XML tags.</p>
+     *  OpenOffice.org XML tags.</p>
      *
      *  <p>This method uses the subclass
      *  <code>getOfficeClassAttribute</code> method to get the

Modified: openoffice/branches/alg/clibboard/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/OfficeDocument.java
URL: http://svn.apache.org/viewvc/openoffice/branches/alg/clibboard/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/OfficeDocument.java?rev=1434615&r1=1434614&r2=1434615&view=diff
==============================================================================
--- openoffice/branches/alg/clibboard/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/OfficeDocument.java (original)
+++ openoffice/branches/alg/clibboard/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/OfficeDocument.java Thu Jan 17 11:06:13 2013
@@ -1022,7 +1022,7 @@ public abstract class OfficeDocument
 
     /**
      *  <p>Creates a new DOM <code>Document</code> containing minimum
-     *  OpenOffice XML tags.</p>
+     *  OpenOffice.org XML tags.</p>
      *
      *  <p>This method uses the subclass
      *  <code>getOfficeClassAttribute</code> method to get the
@@ -1061,7 +1061,7 @@ public abstract class OfficeDocument
 
     /**
      *  <p>Creates a new DOM <code>Document</code> containing minimum
-     *  OpenOffice XML tags.</p>
+     *  OpenOffice.org XML tags.</p>
      *
      *  <p>This method uses the subclass
      *  <code>getOfficeClassAttribute</code> method to get the

Modified: openoffice/branches/alg/clibboard/main/xmerge/source/xmerge/java/org/openoffice/xmerge/util/OfficeUtil.java
URL: http://svn.apache.org/viewvc/openoffice/branches/alg/clibboard/main/xmerge/source/xmerge/java/org/openoffice/xmerge/util/OfficeUtil.java?rev=1434615&r1=1434614&r2=1434615&view=diff
==============================================================================
--- openoffice/branches/alg/clibboard/main/xmerge/source/xmerge/java/org/openoffice/xmerge/util/OfficeUtil.java (original)
+++ openoffice/branches/alg/clibboard/main/xmerge/source/xmerge/java/org/openoffice/xmerge/util/OfficeUtil.java Thu Jan 17 11:06:13 2013
@@ -43,7 +43,7 @@ public class OfficeUtil implements Offic
     
     /**
      * <p>Method to replace whitespace character within text with appropriate 
-     *    OpenOffice tags.</p>
+     *    OpenOffice.org XML tags.</p>
      *
      * @param   text      The text to parse for whitespace.
      *

Modified: openoffice/branches/alg/clibboard/main/xmerge/util/build.xml
URL: http://svn.apache.org/viewvc/openoffice/branches/alg/clibboard/main/xmerge/util/build.xml?rev=1434615&r1=1434614&r2=1434615&view=diff
==============================================================================
--- openoffice/branches/alg/clibboard/main/xmerge/util/build.xml (original)
+++ openoffice/branches/alg/clibboard/main/xmerge/util/build.xml Thu Jan 17 11:06:13 2013
@@ -53,8 +53,8 @@
 	         nodeprecated="true"
 	         nodeprecatedlist="true"
              use="true"
-             Doctitle="OpenOffice XMerge API"
-             windowtitle="OpenOffice XMerge API"
+             Doctitle="Apache OpenOffice XMerge API"
+             windowtitle="Apache OpenOffice XMerge API"
              classpathref="classpath">
             <fileset dir="../source/bridge" defaultexcludes="yes">
                <include name="**/*.java"/>

Modified: openoffice/branches/alg/clibboard/main/xmerge/util/xmerge.mf
URL: http://svn.apache.org/viewvc/openoffice/branches/alg/clibboard/main/xmerge/util/xmerge.mf?rev=1434615&r1=1434614&r2=1434615&view=diff
==============================================================================
--- openoffice/branches/alg/clibboard/main/xmerge/util/xmerge.mf (original)
+++ openoffice/branches/alg/clibboard/main/xmerge/util/xmerge.mf Thu Jan 17 11:06:13 2013
@@ -1,8 +1,8 @@
 Manifest-Version: 1.0
 Main-Class: org.openoffice.xmerge.test.Driver
 Class-Path: xml-apis.jar xercesImpl.jar serializer.jar
-Specification-Title: OpenOffice XMerge Framework
-Specification-Vendor: OpenOffice.org
+Specification-Title: Apache OpenOffice XMerge Framework
+Specification-Vendor: Apache OpenOffice
 Specification-Version: 0.6.0
 Implementation-Version: #IMPL-VERSION#
 

Modified: openoffice/branches/alg/clibboard/main/xmlhelp/source/cxxhelp/provider/makefile.mk
URL: http://svn.apache.org/viewvc/openoffice/branches/alg/clibboard/main/xmlhelp/source/cxxhelp/provider/makefile.mk?rev=1434615&r1=1434614&r2=1434615&view=diff
==============================================================================
--- openoffice/branches/alg/clibboard/main/xmlhelp/source/cxxhelp/provider/makefile.mk (original)
+++ openoffice/branches/alg/clibboard/main/xmlhelp/source/cxxhelp/provider/makefile.mk Thu Jan 17 11:06:13 2013
@@ -39,7 +39,7 @@ NO_BSYMBOLIC=TRUE
 # technique though, so this warning is plain wrong and has been fixed 
 # in gcc 4.3. Unfortunately there is no way at all to suppress this warning.
 # Some files in this directory use zero allocated arrays, we need to
-# diable the WaE mechanism for the GCC 4.2.x series.
+# disable the WaE mechanism for the GCC 4.2.x series.
 .IF "$(COM)"=="GCC"
 .IF "$(CCNUMVER)">="000400020000" && "$(CCNUMVER)"<="000400020003"
 CFLAGSWERRCXX:=

Modified: openoffice/branches/alg/clibboard/main/xmlsecurity/source/dialogs/digitalsignaturesdialog.src
URL: http://svn.apache.org/viewvc/openoffice/branches/alg/clibboard/main/xmlsecurity/source/dialogs/digitalsignaturesdialog.src?rev=1434615&r1=1434614&r2=1434615&view=diff
==============================================================================
--- openoffice/branches/alg/clibboard/main/xmlsecurity/source/dialogs/digitalsignaturesdialog.src (original)
+++ openoffice/branches/alg/clibboard/main/xmlsecurity/source/dialogs/digitalsignaturesdialog.src Thu Jan 17 11:06:13 2013
@@ -200,7 +200,7 @@ ErrorBox RID_XMLSECDLG_OLD_ODF_FORMAT
     Buttons = WB_OK ;
     DefButton = WB_DEF_OK ;
     Message [ en-US ] = 
-		"This document contains signatures in ODF 1.1 (OpenOffice.org 2.x) format. "
+		"This document contains signatures in ODF 1.1 format. "
 		"Signing documents in %PRODUCTNAME %PRODUCTVERSION requires ODF 1.2 format version. "
 		"Thus no signatures can be added or removed to this document.\n\n"
 		"Save document in ODF 1.2 format and add all desired signatures again.";

Modified: openoffice/branches/alg/clibboard/main/xmlsecurity/source/xmlsec/nss/nssinitializer.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/alg/clibboard/main/xmlsecurity/source/xmlsec/nss/nssinitializer.cxx?rev=1434615&r1=1434614&r2=1434615&view=diff
==============================================================================
--- openoffice/branches/alg/clibboard/main/xmlsecurity/source/xmlsec/nss/nssinitializer.cxx (original)
+++ openoffice/branches/alg/clibboard/main/xmlsecurity/source/xmlsec/nss/nssinitializer.cxx Thu Jan 17 11:06:13 2013
@@ -87,7 +87,7 @@ using ::rtl::OString;
 
 #define IMPLEMENTATION_NAME "com.sun.star.xml.security.bridge.xmlsec.NSSInitializer_NssImpl"
 
-#define ROOT_CERTS "Root Certs for OpenOffice.org"
+#define ROOT_CERTS "Root Certs for Apache OpenOffice"
 
 extern "C" void nsscrypto_finalize();
 

Propchange: openoffice/branches/alg/clibboard/test/
------------------------------------------------------------------------------
  Merged /openoffice/trunk/test:r1428975-1431511,1431513-1434611

Modified: openoffice/branches/alg/clibboard/test/build.xml
URL: http://svn.apache.org/viewvc/openoffice/branches/alg/clibboard/test/build.xml?rev=1434615&r1=1434614&r2=1434615&view=diff
==============================================================================
--- openoffice/branches/alg/clibboard/test/build.xml (original)
+++ openoffice/branches/alg/clibboard/test/build.xml Thu Jan 17 11:06:13 2013
@@ -144,7 +144,7 @@
 		</condition>
 		<pathconvert property="openoffice.pack" setonempty="false">
 			<path>
-				<fileset dir="${env.SRC_ROOT}/instsetoo_native/${env.INPATH}/OpenOffice/archive/install/en-US" includes="*.tar.gz,*.zip"  erroronmissingdir="false"/>
+				<fileset dir="${env.SRC_ROOT}/instsetoo_native/${env.INPATH}/Apache_OpenOffice/archive/install/en-US" includes="*.tar.gz,*.zip"  erroronmissingdir="false"/>
 			</path>
 		</pathconvert>
 		<condition property="test.arg0" value="-Dopenoffice.pack=${openoffice.pack}">

Modified: openoffice/branches/alg/clibboard/test/testcommon/source/org/openoffice/test/Run.java
URL: http://svn.apache.org/viewvc/openoffice/branches/alg/clibboard/test/testcommon/source/org/openoffice/test/Run.java?rev=1434615&r1=1434614&r2=1434615&view=diff
==============================================================================
--- openoffice/branches/alg/clibboard/test/testcommon/source/org/openoffice/test/Run.java (original)
+++ openoffice/branches/alg/clibboard/test/testcommon/source/org/openoffice/test/Run.java Thu Jan 17 11:06:13 2013
@@ -28,6 +28,7 @@ import java.util.logging.Level;
 import org.junit.runner.JUnitCore;
 import org.junit.runner.Result;
 import org.junit.runner.notification.RunListener;
+import org.junit.runner.notification.Failure;
 import org.openoffice.test.common.FileUtil;
 import org.openoffice.test.common.Logger;
 import org.openoffice.test.common.NamedRequest;
@@ -142,10 +143,15 @@ public class Run {
 		int code = 0;
 		for (NamedRequest request : requests) {
 			Result result = core.run(request.getRunner());
-			if (!result.wasSuccessful())
+			if (!result.wasSuccessful()) {
 				code = 1;
+				java.util.List<Failure> failureList = result.getFailures();
+				for( Failure f: failureList)
+					log.log( Level.SEVERE, "Failure in "+request.getName()+" :"+ f.toString(), f.getException());
+			}
 		}
 		
 		System.exit(code);
 	}
 }
+

Modified: openoffice/branches/alg/clibboard/test/testcommon/source/org/openoffice/test/common/XMLReporter.java
URL: http://svn.apache.org/viewvc/openoffice/branches/alg/clibboard/test/testcommon/source/org/openoffice/test/common/XMLReporter.java?rev=1434615&r1=1434614&r2=1434615&view=diff
==============================================================================
--- openoffice/branches/alg/clibboard/test/testcommon/source/org/openoffice/test/common/XMLReporter.java (original)
+++ openoffice/branches/alg/clibboard/test/testcommon/source/org/openoffice/test/common/XMLReporter.java Thu Jan 17 11:06:13 2013
@@ -177,9 +177,10 @@ public class XMLReporter extends RunList
 			System.setProperty("info.os.name", SystemUtil.getOSName());
 			System.setProperty("info.os.version", SystemUtil.getOSVersion());
 			System.setProperty("info.os.arch", SystemUtil.getOSArch());
-			System.setProperty("info.os.arch", SystemUtil.getOSArch());
-			System.setProperty("info.ip", SystemUtil.getIPAddress());
-			System.setProperty("info.hostname", SystemUtil.getHostName());
+			String ipaddrStr = SystemUtil.getIPAddress();
+			System.setProperty("info.ip", (ipaddrStr!=null) ? ipaddrStr : "UNKNOWN");
+			String hostnameStr = SystemUtil.getHostName();
+			System.setProperty("info.hostname", (hostnameStr!=null) ? hostnameStr : "UNKNOWN");
 			Set<Entry<Object, Object>> entries = System.getProperties().entrySet();
 			for (Entry<Object, Object> e : entries) {
 				Element prop = doc.createElement("property");
@@ -198,3 +199,4 @@ public class XMLReporter extends RunList
 	}
 
 }
+
--- openoffice/branches/alg/clibboard/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/DocumentDeserializerImpl.java (original)
+++ openoffice/branches/alg/clibboard/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/DocumentDeserializerImpl.java Thu Jan 17 11:06:13 2013
@@ -53,7 +53,7 @@ import org.w3c.dom.Element;
  * org.openoffice.xmerge.converter.xml.sxw.pocketword.PluginFactoryImpl
  * PluginFactoryImpl}.</p>
  *
  * <p>This converts a Pocket Word file to an OpenOffice Writer XML DOM.</p>
  *
  * @author  Mark Murnane
  * @version 1.1
@@ -94,7 +94,7 @@ public final class DocumentDeserializerI
     
     /**
      *  <p>Convert the data passed into the <code>DocumentDeserializer</code>
      *  constructor into the OpenOffice Writer <code>Document</code>
      *  format.</p>
      *
      *  <p>This method may or may not be thread-safe.  It is expected
@@ -120,7 +120,7 @@ public final class DocumentDeserializerI
         }
         catch (Exception e) {
             e.printStackTrace();
-            throw new ConvertException("Error building OpenOffice Writer DOM: "
+            throw new ConvertException("Error building OpenOffice.org XML Writer DOM: "
                                         + e.toString());
             
         }
@@ -53,7 +53,7 @@ import org.w3c.dom.Element;
  * PluginFactoryImpl}.</p>
  *
- * <p>This converts a Pocket Word file to an OpenOffice Writer XML DOM.</p>
+ * <p>This converts a Pocket Word file to an OpenOffice.org XML Writer DOM.</p>
  *
  * @author  Mark Murnane
@@ -94,7 +94,7 @@ public final class DocumentDeserializerI
     /**
      *  <p>Convert the data passed into the <code>DocumentDeserializer</code>
-     *  constructor into the OpenOffice Writer <code>Document</code>
+     *  constructor into the OpenOffice.org XML Writer <code>Document</code>
      *  format.</p>
      *

Modified: openoffice/branches/alg/clibboard/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/DocumentSerializerImpl.java
URL: http://svn.apache.org/viewvc/openoffice/branches/alg/clibboard/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/DocumentSerializerImpl.java?rev=1434615&r1=1434614&r2=1434615&view=diff
==============================================================================